@@ -1,4 +1,4 @@
-require "mocha/mini_test"
+require "mocha/minitest"
 
 Mocha::Configuration.warn_when(:stubbing_non_existent_method)
 Mocha::Configuration.warn_when(:stubbing_non_public_method)
